@@ -27,7 +27,7 @@ default.knots<-function(x,num.knots)
 bs.order<-4   
 bs.degree<-bs.order-1   
 
-if (missing(num.knots)) num.knots<-20
+if (missing(num.knots)) num.knots<-20  #10
 
 knots.inner<-seq(min(x),max(x),le=num.knots)
 intervall<-knots.inner[length(knots.inner)]-knots.inner[1]
@@ -62,7 +62,6 @@ event.time <- time[status==1]
 grid<-round(quantile(unique(time),prob=seq(0,1,le=control$number.int)),max(time+1)) #quantile of specified length
 
 
-
 m <- length(grid)
 grid.minus1 <- c(0,grid[1:(m-1)])
 grid.plus1 <- c(grid[2:m],max(time)+2)
@@ -88,7 +87,7 @@ return(list(grid=grid,y.list=Yt.list,m.list=Mt.list,o.list=Ot.list,x=Xt))
 
 ginverse<-function(X,tol=1e-100)
 {
-Xsvd<-svd(X,LINPACK=T)
+Xsvd<-svd(X,LINPACK=TRUE)
 if (is.complex(X)) Xsvd$u<-Conj(Xsvd$u)
 Positive<-Xsvd$d > max(tol * Xsvd$d[1], 0)
 if (all(Positive)) Xsvd$v %*% (1/Xsvd$d * t(Xsvd$u))
@@ -329,7 +328,7 @@ for (i in 1:30) gc()
 ########################################################################
 if (p > 0)
 {  
-variables.t<-Design.variables[,2:ncol(Design.variables),drop=F]
+variables.t<-Design.variables[,2:ncol(Design.variables),drop=FALSE]
 Design.matrix.t<-cbind(Basis.t,eval(parse(text=paste("cbind(",paste("variables.t[,",1:p,"]*Basis.t",sep="",collapse=","),")"))))
 } else
 Design.matrix.t<-Basis.t
@@ -436,7 +435,7 @@ names(teta.b)<-names(teta.b.new)
 ##############################################    
 #likelihood for alpha.t, alpha.b be given#####
 ##############################################
-offset.tij.list<-lapply(1:N,FUN=function(i) matrix(rep(Design.matrix.b[i,],m.list[i]),nrow=m.list[i],byrow=T)%*%teta.b + offset.list[[i]])
+offset.tij.list<-lapply(1:N,FUN=function(i) matrix(rep(Design.matrix.b[i,],m.list[i]),nrow=m.list[i],byrow=TRUE)%*%teta.b + offset.list[[i]])
 unlist.offset.tij.list<-unlist(offset.tij.list)
 
 
@@ -487,8 +486,8 @@ names(teta.t)<-names(teta.t.new)
 ################################
 #update of random effects#######
 ################################
-u.t<-teta.t.new[grep("u.t",names(teta.t),fixed=T)]
-u.b<-teta.b.new[grep("u.b",names(teta.b),fixed=T)]
+u.t<-teta.t.new[grep("u.t",names(teta.t),fixed=TRUE)]
+u.b<-teta.b.new[grep("u.b",names(teta.b),fixed=TRUE)]
 
 
 if (control$print.epoch)
@@ -543,7 +542,7 @@ variance.penalty.old<-c(variance.penalty.t.old,variance.penalty.b.old)
 
 
 #for t-direction
-variance.t.Baseline<-as.vector((crossprod(u.t[grep("Baseline",names(u.t),fixed=T)],Penalty.matrix.t%*%u.t[grep("Baseline",names(u.t),fixed=T)]) + sum(diag(inverse.I.t.u.t[1:K.t,1:K.t]%*%Penalty.matrix.t[1:K.t,1:K.t])))/(K.t-2))
+variance.t.Baseline<-as.vector((crossprod(u.t[grep("Baseline",names(u.t),fixed=TRUE)],Penalty.matrix.t%*%u.t[grep("Baseline",names(u.t),fixed=TRUE)]) + sum(diag(inverse.I.t.u.t[1:K.t,1:K.t]%*%Penalty.matrix.t[1:K.t,1:K.t])))/(K.t-2))
 variance.penalty.t[1]<-variance.t.Baseline
 #############################################################
 #for-loop (in t) for the factor levels of covariables########
@@ -556,7 +555,7 @@ if (p > 0) for (k in 1:p) Penalty.matrix.teta.t[(K.t+(k-1)*K.t+1):(K.t+k*K.t),(K
 
 
 #for b-direction
-variance.b.Baseline<-as.vector((crossprod(u.b[grep("Baseline",names(u.b),fixed=T)],Penalty.matrix.b%*%u.b[grep("Baseline",names(u.b),fixed=T)]) + sum(diag(inverse.I.b.u.b[1:K.b,1:K.b]%*%Penalty.matrix.b[1:K.b,1:K.b])))/(K.b-2))
+variance.b.Baseline<-as.vector((crossprod(u.b[grep("Baseline",names(u.b),fixed=TRUE)],Penalty.matrix.b%*%u.b[grep("Baseline",names(u.b),fixed=TRUE)]) + sum(diag(inverse.I.b.u.b[1:K.b,1:K.b]%*%Penalty.matrix.b[1:K.b,1:K.b])))/(K.b-2))
 variance.penalty.b[1]<-variance.b.Baseline
 #############################################################
 #for-loop (in b) for the factor levels of covariables########
@@ -624,7 +623,7 @@ log.lik.margin.t.list[[iter.epoch]]<-log.lik.margin.t
 log.lik.margin.b.list[[iter.epoch]]<-log.lik.margin.b
   
 
-} #end if (control$method !="fix") else
+} #end for (iter.epoch in 1:control$niter.epoch)
 
 
 
@@ -792,15 +791,15 @@ names(var.random)<-sub("u","variance.u",names(var.random))
 ######################################################################
 #varying coefficients for Baseline and covariables####################
 ######################################################################
-alpha.t.Baseline<-B.grid.t%*%u.t[grep("Baseline",names(u.t),fixed=T)]
-alpha.b.Baseline<-B.grid.b%*%u.b[grep("Baseline",names(u.b),fixed=T)]
+alpha.t.Baseline<-B.grid.t%*%u.t[grep("Baseline",names(u.t),fixed=TRUE)]
+alpha.b.Baseline<-B.grid.b%*%u.b[grep("Baseline",names(u.b),fixed=TRUE)]
 
 if (p > 0)
 {
 for (k in 1:p)
   {
-assign(paste("alpha.t.",factor.names[k+1],sep=""),B.grid.t%*%u.t[grep(paste("u.t.",factor.names[k+1],sep=""),names(u.t),fixed=T)])  
-assign(paste("alpha.b.",factor.names[k+1],sep=""),B.grid.b%*%u.b[grep(paste("u.b.",factor.names[k+1],sep=""),names(u.b),fixed=T)])
+assign(paste("alpha.t.",factor.names[k+1],sep=""),B.grid.t%*%u.t[grep(paste("u.t.",factor.names[k+1],sep=""),names(u.t),fixed=TRUE)])  
+assign(paste("alpha.b.",factor.names[k+1],sep=""),B.grid.b%*%u.b[grep(paste("u.b.",factor.names[k+1],sep=""),names(u.b),fixed=TRUE)])
 }
 }
 
